@@ -251,31 +251,6 @@ class SecureNamespace:
         )
 
 
-class OpenNamespace:
-    """Open user namespace - Returns DSN string for dominus_open database."""
-
-    def __init__(self, _execute_command):
-        self._execute = _execute_command
-
-    async def dsn(self) -> str:
-        """
-        Get the full DSN connection string for open_user role.
-
-        Returns the complete PostgreSQL connection URI for the dominus_open
-        database that can be used directly by clients to connect.
-        """
-        return await self._execute("sql.open.get_dsn")
-
-
-class HealthNamespace:
-    """Health check operations namespace."""
-
-    def __init__(self, _execute_command):
-        self._execute = _execute_command
-
-    async def check(self) -> Dict[str, Any]:
-        """Check health of all services."""
-        return await self._execute("health.check")
 
 
 class Dominus:
@@ -324,10 +299,8 @@ class Dominus:
 
         self._execute = _execute_command
 
-        # Initialize minimal namespaces
+        # Initialize legacy flat API namespaces (backward compatibility)
         self.secure = SecureNamespace(_execute_command)
-        self.open = OpenNamespace(_execute_command)
-        self.health = HealthNamespace(_execute_command)
 
         # Initialize portal namespace (needs client reference for _request)
         from .namespaces.portal import PortalNamespace
@@ -337,6 +310,45 @@ class Dominus:
         from .namespaces.fastapi import FastAPINamespace
         self.fastapi = FastAPINamespace(self)
 
+        # Initialize all namespaces (matching Node.js SDK pattern)
+        from .namespaces.db import DbNamespace
+        from .namespaces.auth import AuthNamespace
+        from .namespaces.ddl import DdlNamespace
+        from .namespaces.files import FilesNamespace
+        from .namespaces.admin import AdminNamespace
+        from .namespaces.secure import SecureNamespace as SecureNS
+        from .namespaces.secrets import SecretsNamespace
+        from .namespaces.redis import RedisNamespace
+        from .namespaces.logs import LogsNamespace
+        from .namespaces.courier import CourierNamespace
+        from .namespaces.health import HealthNamespace
+        from .namespaces.open import OpenNamespace
+
+        # Core namespaces
+        self.db = DbNamespace(self)
+        self.auth = AuthNamespace(self)
+        self.ddl = DdlNamespace(self)
+        self.files = FilesNamespace(self)
+        self.admin = AdminNamespace(self)
+
+        # Additional namespaces (Node.js SDK parity)
+        self.secrets = SecretsNamespace(self)
+        self.redis = RedisNamespace(self)
+        self.logs = LogsNamespace(self)
+        self.courier = CourierNamespace(self)
+        self.health = HealthNamespace(self)
+        self.open = OpenNamespace(self)
+
+        # Secure namespace with proper audit context support
+        self.db_secure = SecureNS(self)
+
+        # Oracle namespace (Speech-to-Text streaming)
+        from .namespaces.oracle import OracleNamespace
+        self.oracle = OracleNamespace(self)
+
+        # Alias for Node.js SDK parity (stt = oracle)
+        self.stt = self.oracle
+
         # Cache for JWT public key
         self._public_key_cache = None
 
